# icure_dart_sdk.model.PatientDto

## Load the model package
```dart
import 'package:icure_dart_sdk/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **String** | the Id of the patient. We encourage using either a v4 UUID or a HL7 Id. | 
**identifier** | [**List<IdentifierDto>**](IdentifierDto.md) |  | [default to const []]
**rev** | **String** | the revision of the patient in the database, used for conflict management / optimistic locking. | [optional] 
**created** | **int** | The timestamp (unix epoch in ms) of creation of this entity, will be filled automatically if missing. Not enforced by the application server. | [optional] 
**modified** | **int** | The date (unix epoch in ms) of the latest modification of this entity, will be filled automatically if missing. Not enforced by the application server. | [optional] 
**author** | **String** | The id of the User that has created this entity, will be filled automatically if missing. Not enforced by the application server. | [optional] 
**responsible** | **String** | The id of the HealthcareParty that is responsible for this entity, will be filled automatically if missing. Not enforced by the application server. | [optional] 
**tags** | [**Set<CodeStubDto>**](CodeStubDto.md) | A tag is an item from a codification system that qualifies an entity as being member of a certain class, whatever the value it might have taken. If the tag qualifies the content of a field, it means that whatever the content of the field, the tag will always apply. For example, the label of a field is qualified using a tag. LOINC is a codification system typically used for tags. | [default to const {}]
**codes** | [**Set<CodeStubDto>**](CodeStubDto.md) | A code is an item from a codification system that qualifies the content of this entity. SNOMED-CT, ICPC-2 or ICD-10 codifications systems can be used for codes | [default to const {}]
**endOfLife** | **int** | Soft delete (unix epoch in ms) timestamp of the object. | [optional] 
**deletionDate** | **int** | hard delete (unix epoch in ms) timestamp of the object. Filled automatically when deletePatient is called. | [optional] 
**firstName** | **String** | the firstname (name) of the patient. | [optional] 
**lastName** | **String** | the lastname (surname) of the patient. This is the official lastname that should be used for official administrative purposes. | [optional] 
**names** | [**List<PersonNameDto>**](PersonNameDto.md) | the list of all names of the patient, also containing the official full name information. Ordered by preference of use. First element is therefore the official name used for the patient in the application | [default to const []]
**companyName** | **String** | the name of the company this patient is member of. | [optional] 
**languages** | **List<String>** | the list of languages spoken by the patient ordered by fluency (alpha-2 code http://www.loc.gov/standards/iso639-2/ascii_8bits.html). | [default to const []]
**addresses** | [**List<AddressDto>**](AddressDto.md) | the list of addresses (with address type). | [default to const []]
**civility** | **String** | Mr., Ms., Pr., Dr. ... | [optional] 
**gender** | **String** | the gender of the patient: male, female, indeterminate, changed, changedToMale, changedToFemale, unknown | [optional] 
**birthSex** | **String** | the birth sex of the patient: male, female, indeterminate, unknown | [optional] 
**mergeToPatientId** | **String** | The id of the patient this patient has been merged with. | [optional] 
**mergedIds** | **Set<String>** | The ids of the patients that have been merged inside this patient. | [default to const {}]
**alias** | **String** | An alias of the person, nickname, ... | [optional] 
**active** | **bool** | Is the patient active (boolean). | [default to true]
**deactivationReason** | **String** | When not active, the reason for deactivation. | [default to 'DeactivationReason.none']
**ssin** | **String** | Social security inscription number. | [optional] 
**maidenName** | **String** | Lastname at birth (can be different of the current name), depending on the country, must be used to design the patient . | [optional] 
**spouseName** | **String** | Lastname of the spouse for a married woman, depending on the country, can be used to design the patient. | [optional] 
**partnerName** | **String** | Lastname of the partner, should not be used to design the patient. | [optional] 
**personalStatus** | **String** | any of `single`, `in_couple`, `married`, `separated`, `divorced`, `divorcing`, `widowed`, `widower`, `complicated`, `unknown`, `contract`, `other`. | [optional] 
**dateOfBirth** | **int** | The birthdate encoded as a fuzzy date on 8 positions (YYYYMMDD) MM and/or DD can be set to 00 if unknown (19740000 is a valid date). | [optional] 
**dateOfDeath** | **int** | The date of death encoded as a fuzzy date on 8 positions (YYYYMMDD) MM and/or DD can be set to 00 if unknown (19740000 is a valid date). | [optional] 
**timestampOfLatestEidReading** | **int** | Timestamp of the latest validation of the eID of the person.. | [optional] 
**placeOfBirth** | **String** | The place of birth. | [optional] 
**placeOfDeath** | **String** | The place of death. | [optional] 
**deceased** | **bool** | Is the patient deceased. | [optional] 
**education** | **String** | The level of education (college degree, undergraduate, phd). | [optional] 
**profession** | **String** | The current professional activity. | [optional] 
**note** | **String** | A text note (can be confidential, encrypted by default). | [optional] 
**administrativeNote** | **String** | An administrative note, not confidential. | [optional] 
**nationality** | **String** | The nationality of the patient. | [optional] 
**race** | **String** | The race of the patient. | [optional] 
**ethnicity** | **String** | The ethnicity of the patient. | [optional] 
**preferredUserId** | **String** | The id of the user that usually handles this patient. | [optional] 
**picture** | **String** | A picture usually saved in JPEG format. | [optional] 
**externalId** | **String** | An external (from another source) id with no guarantee or requirement for unicity . | [optional] 
**insurabilities** | [**List<InsurabilityDto>**](InsurabilityDto.md) | List of insurance coverages (of class Insurability, see below). | [default to const []]
**partnerships** | [**List<PartnershipDto>**](PartnershipDto.md) | List of partners, or persons of contact (of class Partnership, see below). | [default to const []]
**patientHealthCareParties** | [**List<PatientHealthCarePartyDto>**](PatientHealthCarePartyDto.md) | Links (usually for therapeutic reasons) between this patient and healthcare parties (of class PatientHealthcareParty). | [default to const []]
**financialInstitutionInformation** | [**List<FinancialInstitutionInformationDto>**](FinancialInstitutionInformationDto.md) | Financial information (Bank, bank account) used to reimburse the patient. | [default to const []]
**medicalHouseContracts** | [**List<MedicalHouseContractDto>**](MedicalHouseContractDto.md) | Contracts between the patient and the healthcare entity. | [default to const []]
**patientProfessions** | [**List<CodeStubDto>**](CodeStubDto.md) | Codified list of professions exercised by this patient. | [default to const []]
**parameters** | [**Map<String, List<String>>**](List.md) | Extra parameters | [default to const {}]
**properties** | [**Set<PropertyStubDto>**](PropertyStubDto.md) | Extra properties | [default to const {}]
**hcPartyKeys** | [**Map<String, List<String>>**](List.md) | For each couple of HcParties (delegator and delegate), this map contains the exchange AES key. The delegator is always this hcp, the key of the map is the id of the delegate. The AES exchange key is encrypted using RSA twice : once using this hcp public key (index 0 in the Array) and once using the other hcp public key (index 1 in the Array). For a pair of HcParties. Each HcParty always has one AES exchange key for himself. | [default to const {}]
**privateKeyShamirPartitions** | **Map<String, String>** | The privateKeyShamirPartitions are used to share this hcp's private RSA key with a series of other hcParties using Shamir's algorithm. The key of the map is the hcp Id with whom this partition has been shared. The value is \"threshold⎮partition in hex\" encrypted using the the partition's holder's public RSA key | [default to const {}]
**publicKey** | **String** | The public key of this hcp | [optional] 
**secretForeignKeys** | **Set<String>** | The secretForeignKeys are filled at the to many end of a one to many relationship (for example inside Contact for the Patient -> Contacts relationship). Used when we want to find all contacts for a specific patient. These keys are in clear. You can have several to partition the medical document space. | [default to const {}]
**cryptedForeignKeys** | [**Map<String, Set<DelegationDto>>**](Set.md) | The secretForeignKeys are filled at the to many end of a one to many relationship (for example inside Contact for the Patient -> Contacts relationship). Used when we want to find the patient for a specific contact. These keys are the encrypted id (using the hcParty key for the delegate) that can be found in clear inside the patient. ids encrypted using the hcParty keys. | [default to const {}]
**delegations** | [**Map<String, Set<DelegationDto>>**](Set.md) | When a document is created, the responsible generates a cryptographically random master key (never to be used for something else than referencing from other entities). He/she encrypts it using his own AES exchange key and stores it as a delegation. The responsible is thus always in the delegations as well | [default to const {}]
**encryptionKeys** | [**Map<String, Set<DelegationDto>>**](Set.md) | When a document needs to be encrypted, the responsible generates a cryptographically random master key (different from the delegation key, never to appear in clear anywhere in the db. He/she encrypts it using his own AES exchange key and stores it as a delegation | [default to const {}]
**encryptedSelf** | **String** | The base64 encoded data of this object, formatted as JSON and encrypted in AES using the random master key from encryptionKeys. | [optional] 
**medicalLocationId** | **String** | The id of the medical location where this entity was created. | [optional] 
**nonDuplicateIds** | **Set<String>** |  | [default to const {}]
**encryptedAdministrativesDocuments** | **Set<String>** |  | [default to const {}]
**comment** | **String** |  | [optional] 
**warning** | **String** |  | [optional] 
**fatherBirthCountry** | [**CodeStubDto**](CodeStubDto.md) |  | [optional] 
**birthCountry** | [**CodeStubDto**](CodeStubDto.md) |  | [optional] 
**nativeCountry** | [**CodeStubDto**](CodeStubDto.md) |  | [optional] 
**socialStatus** | [**CodeStubDto**](CodeStubDto.md) |  | [optional] 
**mainSourceOfIncome** | [**CodeStubDto**](CodeStubDto.md) |  | [optional] 
**schoolingInfos** | [**List<SchoolingInfoDto>**](SchoolingInfoDto.md) |  | [default to const []]
**employementInfos** | [**List<EmploymentInfoDto>**](EmploymentInfoDto.md) |  | [default to const []]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


